@@ -6,6 +6,9 @@
 #'
 #' @param date A date in "yyyy-mm-dd" format, or any format that can be
 #' coerced to a date with `as.Date()`.
+#' @param updated If `TRUE`, returns all bathrooms updated _or_ added
+#' since the given date. Defaults to `FALSE`, which only returns bathrooms
+#' added since the given date.
 #'
 #' @inheritParams rfg_all_restrooms
 #'
@@ -13,14 +16,14 @@
 #' the given date.
 #' @export
 #'
-#' @examples \donttest{
-#'
+#' @examples
+#' \donttest{
+#' 
 #' q <- rfg_date("2017-11-04")
-#'
 #' }
-
-rfg_date <- function(date = NULL, accessible = FALSE,
-                     unisex = FALSE, verbose = TRUE, tidy = FALSE) {
+#' 
+rfg_date <- function(date = NULL, accessible = FALSE, unisex = FALSE,
+                     updated = FALSE, verbose = TRUE, tidy = FALSE) {
   if (is.null(date)) stop("Please enter a date", call. = FALSE)
 
   date <- as.Date(date)
@@ -29,9 +32,11 @@ rfg_date <- function(date = NULL, accessible = FALSE,
 
   unisex_query <- unisex_function(unisex)
 
+  updated_query <- ifelse(updated == TRUE, "updated=true&", "")
+
   query <- paste0(
-    base_url, "/by_date.json?", ada_query, unisex_query,
-    "&day=", format(date, "%d"), "&month=", format(date, "%m"),
+    base_url, "/by_date.json?", ada_query, unisex_query, updated_query,
+    "day=", trimws(format(date, "%e")), "&month=", format(date, "%m"),
     "&year=", format(date, "%y"), "&per_page=1"
   )
 
