@@ -2,7 +2,7 @@
 
 unisex_function <- function(unisex) {
   if (unisex == TRUE) {
-    "&unisex=TRUE"
+    "unisex=true&"
   } else {
     ""
   }
